@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-search-dialog.c,v 1.3 2006/01/02 15:54:50 pborelli Exp $
+ * $Id: gedit-search-dialog.c,v 1.5 2006/03/05 22:33:53 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -111,14 +111,32 @@ gedit_search_dialog_get_property (GObject    *object,
 	}
 }
 
+static gboolean
+gedit_search_dialog_focus_in_event (GtkWidget     *widget,
+				    GdkEventFocus *event)
+{
+	GeditSearchDialog *dlg = GEDIT_SEARCH_DIALOG (widget);
+	GtkWidget *entry = dlg->priv->search_entry;
+	
+	if (!GTK_WIDGET_HAS_FOCUS (entry))
+	{
+		gtk_widget_grab_focus (entry);
+		gtk_editable_set_position (GTK_EDITABLE (entry), -1);
+	}
+
+	return GTK_WIDGET_CLASS (gedit_search_dialog_parent_class)->focus_in_event (widget, event);
+}
+
 static void 
 gedit_search_dialog_class_init (GeditSearchDialogClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	object_class->set_property = gedit_search_dialog_set_property;
 	object_class->get_property = gedit_search_dialog_get_property;
-
+	widget_class->focus_in_event = gedit_search_dialog_focus_in_event;
+	
 	g_object_class_install_property (object_class, PROP_SHOW_REPLACE,
 					 g_param_spec_boolean ("show-replace",
 					 		       "Show Replace",
@@ -191,20 +209,6 @@ search_entry_changed (GtkEditable       *editable,
 	}
 }
 
-static void
-search_options_changed (GtkToggleButton   *button,
-			GeditSearchDialog *dialog)
-{
-	/* make sure Replace All is reactivated when the options
-	 * become less restrictive */
-	if (!gtk_toggle_button_get_active (button))
-	{
-		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
-						   GEDIT_SEARCH_DIALOG_REPLACE_ALL_RESPONSE,
-						   TRUE);
-	}
-}
-
 static void
 response_handler (GeditSearchDialog *dialog,
 		  gint               response_id,
@@ -351,15 +355,6 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 			  G_CALLBACK (search_entry_changed),
 			  dlg);
 
-	g_signal_connect (dlg->priv->match_case_checkbutton,
-			  "toggled",
-			  G_CALLBACK (search_options_changed),
-			  dlg);
-	g_signal_connect (dlg->priv->entire_word_checkbutton,
-			  "toggled",
-			  G_CALLBACK (search_options_changed),
-			  dlg);
-
 	g_signal_connect (dlg,
 			  "response",
 			  G_CALLBACK (response_handler),
@@ -418,6 +413,10 @@ gedit_search_dialog_set_search_text (GeditSearchDialog *dialog,
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
 					   GEDIT_SEARCH_DIALOG_FIND_RESPONSE,
 					   (text != '\0'));
+					   
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+					   GEDIT_SEARCH_DIALOG_REPLACE_ALL_RESPONSE,
+					   (text != '\0'));					   
 }
 
 /*
