@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c,v 1.2 2005/12/12 17:27:55 pborelli Exp $
+ * $Id: gedit-commands-file.c,v 1.5 2006/02/19 21:46:48 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -104,46 +104,43 @@ load_file_list (GeditWindow         *window,
 		    (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_NORMAL))
 		{
 			const gchar *uri;
-			gboolean     ret;
 
 			uri = (const gchar *)uris->data;
-			ret = _gedit_tab_load (tab,
-					       uri,
-					       encoding,
-					       line_pos,
-					       create);
+
+			_gedit_tab_load (tab,
+					 uri,
+					 encoding,
+					 line_pos,
+					 create);
 
 			uris = g_slist_next (uris);
 			jump_to = FALSE;
 
-			if (ret)
+			if (uris == NULL)
 			{
-				if (uris == NULL)
-				{
-					/* There is only a single file to load */
-					gchar *uri_for_display;
+				/* There is only a single file to load */
+				gchar *uri_for_display;
 
-					uri_for_display = gnome_vfs_format_uri_for_display (uri);
+				uri_for_display = gnome_vfs_format_uri_for_display (uri);
 
-					gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-								       window->priv->generic_message_cid,
-								       _("Loading file '%s'\342\200\246"),
-								       uri_for_display);
+				gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
+							       window->priv->generic_message_cid,
+							       _("Loading file '%s'\342\200\246"),
+							       uri_for_display);
 
-					g_free (uri_for_display);
+				g_free (uri_for_display);
 
-					flash = FALSE;
-				}
-
-				++loaded_files;
+				flash = FALSE;
 			}
+
+			++loaded_files;
 		}
 	}
 
 	while (uris != NULL)
 	{
 		g_return_val_if_fail (uris->data != NULL, 0);
-
+		
 		tab = gedit_window_create_tab_from_uri (window,
 							(const gchar *)uris->data,
 							encoding,
