@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit.c,v 1.127 2005/12/29 13:46:03 pborelli Exp $
+ * $Id: gedit.c,v 1.133 2006/03/03 16:31:17 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,6 +36,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
+#include <glib/goption.h>
 #include <gdk/gdkx.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
@@ -65,85 +66,55 @@ static gchar *encoding_charset = NULL;
 static const GeditEncoding *encoding;
 static gboolean new_window_option = FALSE;
 static gboolean new_document_option = FALSE;
+static gchar **remaining_args = NULL;
 static GSList *file_list = NULL;
 
-static const struct poptOption options [] =
+static const GOptionEntry options [] =
 {
-	{ "encoding", '\0', POPT_ARG_STRING, &encoding_charset,	0,
-	  N_("Set the character encoding to be used to open the files listed on the command line"), NULL },
+	{ "encoding", '\0', 0, G_OPTION_ARG_STRING, &encoding_charset,
+	  N_("Set the character encoding to be used to open the files listed on the command line"), "ENCODING" /* When out of string freeze, use N_("ENCODING") */ },
 
-	{ "new-window", '\0', POPT_ARG_NONE, &new_window_option, 0,
+	{ "new-window", '\0', 0, G_OPTION_ARG_NONE, &new_window_option,
 	  N_("Create a new toplevel window in an existing instance of gedit"), NULL },
 
-	{ "new-document", '\0', POPT_ARG_NONE, &new_document_option, 0,
+	{ "new-document", '\0', 0, G_OPTION_ARG_NONE, &new_document_option,
 	  N_("Create a new document in an existing instance of gedit"), NULL },
 
-	{NULL, '\0', 0, NULL, 0}
+	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &remaining_args,
+	  NULL, NULL }, /* collects file arguments */
+
+	{NULL}
 };
 
 static void
 gedit_get_command_line_data (GnomeProgram *program)
 {
-	GValue value = { 0, };
-	poptContext ctx;
-	gchar **args;
-
-	g_value_init (&value, G_TYPE_POINTER);
-	g_object_get_property (G_OBJECT (program),
-			       GNOME_PARAM_POPT_CONTEXT,
-			       &value);
-	ctx = g_value_get_pointer (&value);
-	g_value_unset (&value);
-
-	args = (gchar **) poptGetArgs(ctx);
-
-	if (args)
+	if (remaining_args)
 	{
 		gint i;
 
-		for (i = 0; args[i]; i++) 
+		for (i = 0; remaining_args[i]; i++) 
 		{
-			if (*args[i] == '+')
+			if (*remaining_args[i] == '+')
 			{
-				if (*(args[i] + 1) == '\0')
+				if (*(remaining_args[i] + 1) == '\0')
 					/* goto the last line of the document */
 					line_position = G_MAXINT;
 				else
-					line_position = atoi (args[i] + 1);
+					line_position = atoi (remaining_args[i] + 1);
 			}
 			else
 			{
-				gchar *uri;
 				gchar *canonical_uri;
-
-				/* Note for the future: 
-				 *
-				 * <federico> paolo: and flame whoever tells 
-				 * you that file:///gnome/test_files/hëllò 
-				 * doesn't work --- that's not a valid URI
-				 *
-				 * <paolo> federico: well, another solution that 
-				 * does not requires patch to _from_shell_args 
-				 * is to check that the string returned by it 
-				 * contains only ASCII chars
-				 * <federico> paolo: hmmmm, isn't there 
-				 * gnome_vfs_is_uri_valid() or something?
-				 * <paolo>: I will use gedit_utils_is_valid_uri ()
-				 *
-				 */
-				 
-				uri = gnome_vfs_make_uri_from_shell_arg (args[i]);
-				canonical_uri = gnome_vfs_make_uri_canonical (uri);
-				g_free (uri);
 				
-				g_print ("URI: %s\n", canonical_uri);
+				canonical_uri = gedit_utils_make_canonical_uri_from_shell_arg (remaining_args[i]);
 				
-				if (gedit_utils_is_valid_uri (canonical_uri))
+				if (canonical_uri != NULL)
 					file_list = g_slist_prepend (file_list, 
 								     canonical_uri);
 				else
 					g_print (_("%s: malformed file name or URI.\n"),
-						 args[i]);
+						 remaining_args[i]);
 			} 
 		}
 
@@ -160,8 +131,6 @@ gedit_get_command_line_data (GnomeProgram *program)
 		g_free (encoding_charset);
 		encoding_charset = NULL;
 	}
-
-	poptFreeContext (ctx);
 }
 
 static guint32
@@ -208,9 +177,13 @@ on_message_received (const char *message,
 	gchar **commands;
 	gchar **params;
 	gint workspace;
+	gchar *display_name;
+	gint screen_number;
 	gint i;
 	GeditApp *app;
 	GeditWindow *window;
+	GdkDisplay *display;
+	GdkScreen *screen;
 
 	g_return_if_fail (message != NULL);
 
@@ -219,9 +192,16 @@ on_message_received (const char *message,
 	commands = g_strsplit (message, "\v", -1);
 
 	/* header */
-	params = g_strsplit (commands[0], "\t", 2);
-	startup_timestamp = atoi (params[0]); //CHECK if this is safe
-	workspace = atoi (params[1]);
+	params = g_strsplit (commands[0], "\t", 4);
+	startup_timestamp = atoi (params[0]); /* CHECK if this is safe */
+	display_name = g_strdup (params[1]);
+	screen_number = atoi (params[2]);
+	workspace = atoi (params[3]);
+
+	display = gdk_display_open (display_name);
+	screen = gdk_display_get_screen (display, screen_number);
+	g_free (display_name);
+
 	g_strfreev (params);
 
 	/* body */
@@ -275,12 +255,14 @@ on_message_received (const char *message,
 
 	if (new_window_option)
 	{
-		window = gedit_app_create_window (app);
+		window = gedit_app_create_window (app, screen);
 	}
 	else
 	{
 		/* get a window in the current workspace (if exists) and raise it */
-		window = _gedit_app_get_window_in_workspace (app, workspace);
+		window = _gedit_app_get_window_in_workspace (app,
+							     screen,
+							     workspace);
 	}
 
 	if (file_list != NULL)
@@ -336,12 +318,16 @@ on_message_received (const char *message,
 static void
 send_bacon_message (void)
 {
+	GdkScreen *screen;
+	GdkDisplay *display;
+	const gchar *display_name;
+	gint screen_number;
 	gint ws;
 	GString *command;
 
 	/* the messages have the following format:
-	 * <----   header   -----> <----            body             ----->
-	 * timestamp \t workspace \v OP1 \t arg \t arg \v OP2 \t arg \t arg|...
+	 * <---                   header                       ---> <----            body             ----->
+	 * timestamp \t display_name \t screen_number \t workspace \v OP1 \t arg \t arg \v OP2 \t arg \t arg|...
 	 *
 	 * when the arg is a list of uri, they are separated by a space.
 	 * So the delimiters are \v for the commands, \t for the tokens in
@@ -349,14 +335,27 @@ send_bacon_message (void)
 	 * be part of an uri, this way parsing is easier.
 	 */
 
-	ws = gedit_utils_get_current_workspace (gdk_screen_get_default ());
+	gedit_debug (DEBUG_APP);
+
+	screen = gdk_screen_get_default ();
+	display = gdk_screen_get_display (screen);
+
+	display_name = gdk_display_get_name (display);
+	screen_number = gdk_screen_get_number (screen);
+
+	gedit_debug_message (DEBUG_APP, "Display: %s", display_name);
+	gedit_debug_message (DEBUG_APP, "Screen: %d", screen_number);	
+
+	ws = gedit_utils_get_current_workspace (screen);
 
 	command = g_string_new (NULL);
 
 	/* header */
 	g_string_append_printf (command,
-				"%" G_GUINT32_FORMAT "\t%d",
+				"%" G_GUINT32_FORMAT "\t%s\t%d\t%d",
 				startup_timestamp,
+				display_name,
+				screen_number,
 				ws);
 
 	/* NEW-WINDOW command */
@@ -395,6 +394,8 @@ send_bacon_message (void)
 		}
 	}
 
+	gedit_debug_message (DEBUG_APP, "Bacon Message: %s", command->str);
+	
 	bacon_message_connection_send (connection,
 				       command->str);
 
@@ -405,6 +406,7 @@ int
 main (int argc, char *argv[])
 {
 	GnomeProgram *program;
+	GOptionContext *context;
 	GeditWindow *window;
 	GeditApp *app;
 	gboolean restored = FALSE;
@@ -421,11 +423,15 @@ main (int argc, char *argv[])
 	startup_timestamp = get_startup_timestamp();
 
 	gedit_debug_message (DEBUG_APP, "Run gnome_program_init");
+
+	/* Setup command line options */
+	context = g_option_context_new ("[FILE...]"); /* Should be translated when out of string freeze */
+	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	
 	/* Initialize gnome program */
 	program = gnome_program_init ("gedit", VERSION,
 			    LIBGNOMEUI_MODULE, argc, argv,
-			    GNOME_PARAM_POPT_TABLE, options,
+			    GNOME_PARAM_GOPTION_CONTEXT, context,
 			    GNOME_PARAM_HUMAN_READABLE_NAME,
 		            _("Text Editor"),
 			    GNOME_PARAM_APP_DATADIR, DATADIR,
@@ -508,8 +514,8 @@ main (int argc, char *argv[])
 		app = gedit_app_get_default ();
 
 		gedit_debug_message (DEBUG_APP, "Create main window");
-		window = gedit_app_create_window (app);
-		
+		window = gedit_app_create_window (app, NULL);
+
 		if (file_list != NULL)
 		{
 			gedit_debug_message (DEBUG_APP, "Load files");
@@ -539,10 +545,14 @@ main (int argc, char *argv[])
 	gedit_debug_message (DEBUG_APP, "Start gtk-main");		
 	gtk_main();
 
+	bacon_message_connection_free (connection);
+
 	gedit_plugins_engine_shutdown ();
 	gedit_prefs_manager_app_shutdown ();
 	gedit_metadata_manager_shutdown ();
 
+	gnome_accelerators_sync ();
+
 	g_object_unref (program);
 
 	return 0;
